@@ -28,6 +28,7 @@ diagnostics <- function(project = NULL) {
     renv_diagnostics_project,
     renv_diagnostics_status,
     renv_diagnostics_packages,
+    renv_diagnostics_abi,
     renv_diagnostics_profile,
     renv_diagnostics_settings,
     renv_diagnostics_options,
@@ -80,7 +81,12 @@ renv_diagnostics_packages <- function(project) {
   )
 
   # bundle together
-  all <- c(names(lockfile$Packages), names(libstate$Packages), names(recdeps))
+  all <- c(
+    names(lockfile$Packages),
+    names(libstate$Packages),
+    names(recdeps),
+    used
+  )
 
   # sort
   renv_scope_locale(category = "LC_COLLATE", locale = "C")
@@ -187,6 +193,18 @@ renv_diagnostics_packages_dependencies <- function(project) {
 
 }
 
+renv_diagnostics_abi <- function(project) {
+
+  vwritef(header("ABI"))
+  tryCatch(
+    renv_abi_check(),
+    error = function(e) {
+      vwritef(conditionMessage(e))
+    }
+  )
+
+}
+
 renv_diagnostics_profile <- function(project) {
 
   vwritef(header("User Profile"))
