@@ -39,3 +39,7 @@ skip_if_local <- function() {
   ci <- Sys.getenv("CI", unset = NA)
   testthat::skip_if(is.na(ci), "Running tests locally")
 }
+
+skip_on_windows <- function() {
+  testthat::skip_on_os("windows")
+}
