@@ -7,7 +7,7 @@ test_that("library paths set in a user profile are overridden after load", {
 
   renv_tests_scope()
 
-  renv::init()
+  init()
   renv_imbue_impl(project = getwd(), force = TRUE)
 
   profile <- c(
@@ -31,32 +31,46 @@ test_that("library paths set in a user profile are overridden after load", {
 })
 
 test_that(".First is executed; library paths are restored after", {
+
+  skip("only implemented when sandbox running?")
+
   skip_on_cran()
   skip_on_os("windows")
 
   renv_tests_scope()
 
-  renv::init()
+  init()
   renv_imbue_impl(project = getwd(), force = TRUE)
 
   # add a .First to the profile
-  profile <- c(
-    ".First <- function() .libPaths('.')",
-    "source('renv/activate.R')"
-  )
+  profile <- code({
+
+    .First <- function() {
+      writeLines("Hello from .First")
+      .libPaths(".")
+    }
+
+    source("renv/activate.R")
+
+  })
+
   writeLines(profile, con = ".Rprofile")
 
   # ensure profile is executed
   renv_scope_envvars(R_PROFILE_USER = NULL)
 
   # invoke R
-  args <- c("-e", shQuote("writeLines(.libPaths(), 'libpaths.txt')"))
-  output <- system2(R(), args, stdout = FALSE, stderr = FALSE)
-  expect_equal(output, 0L)
+  script <- renv_test_code({
+    print(.libPaths())
+    writeLines(.libPaths(), con = "libpaths.txt")
+  })
+
+  args <- c("-f", shQuote(script))
+  output <- renv_system_exec(R(), args, action = "writing libpaths")
 
   actual <- readLines("libpaths.txt")
   expected <- renv_libpaths_all()
 
-  expect_equal(actual[[1]], expected[[1]])
+  expect_equal(actual[[1L]], expected[[1L]])
 
 })
